Contributing
============

Contributions are welcome and are greatly appreciated! Every little bit
helps, and credit will always be given.

**Table of Contents**

-  `Types of Contributions`_

   -  `Report Bugs`_
   -  `Fix Bugs`_
   -  `Implement Features`_
   -  `Dataset`_
   -  `Improve Documentation`_
   -  `Submit Feedback`_

-  `Documentation`_
-  `Local development environment`_

   -  `Installation`_

-  `Pull Request Guidelines`_

Types of Contributions
======================

Report Bugs
-----------

Report bugs through `Github issue`_.

Please report relevant information and preferably code that exhibits the
problem.

Fix Bugs
--------

Look through the `Github issue`_ for bugs. Anything is open to whoever
wants to implement it.

Implement Features
------------------

Look through the `Github issue`_ or `Malaya-project`_ for features. Any
unassigned ``improvement`` issue is open to whoever wants to implement
it.

Remember, **100% Tensorflow (version 1.10 and above, not 2.0, yet), no
Keras**.

Dataset
-------

Create a new issue in `Github issue`_ related to your data including the
data link or attached it there. If you want to improve current dataset
we have, you can check at `Malaya-Dataset`_.

Or, you can simply email your data if you do not want to expose the data
to public. Malaya will not exposed your data, but we will exposed our
trained models based on your data.

Thanks to,

1. `Fake news`_, contributed by `syazanihussin`_
2. `Speech voice`_, contributed by `Khalil Nooh`_
3. `Speech voice`_, contributed by `Mas Aisyah Ahmad`_
4. `Singlish text dump`_, contributed by `brytjy`_
5. `Singapore news`_, contributed by `brytjy`_

Improve Documentation
---------------------

Malaya could always use better documentation, might have some typos or
uncorrect object names.

Submit Feedback
---------------

The best way to send feedback is to open an issue on `Github issue`_.

Unit test
---------

Test every possible program flow! You can check `unit tests here`_.

Documentation
=============

The latest API

.. _Types of Contributions: #types-of-contributions
.. _Report Bugs: #report-bugs
.. _Fix Bugs: #fix-bugs
.. _Implement Features: #implement-features
.. _Dataset: #dataset
.. _Improve Documentation: #improve-documentation
.. _Submit Feedback: #submit-feedback
.. _Documentation: #documentation
.. _Local development environment: #local-development-environment
.. _Installation: #installation
.. _Pull Request Guidelines: #pull-request-guidelines
.. _Github issue: https://github.com/huseinzol05/Malaya/issues/new
.. _Malaya-project: https://github.com/huseinzol05/Malaya/projects/1
.. _Malaya-Dataset: https://github.com/huseinzol05/Malaya-Dataset
.. _Fake news: https://github.com/huseinzol05/Malaya-Dataset#fake-news
.. _syazanihussin: https://github.com/syazanihussin/FLUX/tree/master/data
.. _Speech voice: https://github.com/huseinzol05/Malaya-Dataset#tolong-sebut
.. _Khalil Nooh: https://www.linkedin.com/in/khalilnooh/
.. _Mas Aisyah Ahmad: https://www.linkedin.com/in/mas-aisyah-ahmad-b46508a9/
.. _Singlish text dump: https://github.com/huseinzol05/malaya-dataset#singlish-text
.. _brytjy: https://github.com/brytjy
.. _Singapore news: https://github.com/huseinzol05/malaya-dataset#singapore-news
.. _unit tests here: https://github.com/huseinzol05/Malaya/tree/master/tests
